@@ -138,19 +138,20 @@ class QueryBuilder:
     def get_count(self) -> int:
         return self._count
 
-    def reset(self) -> None:
+    def reset(self) -> bool:
         self._sql = ''
         self._params = ()
         self._query = None
         self._result = []
         self._count = -1
         self.set_error()
+        return True
 
-    def all(self) -> Union[list, dict]:
+    def all(self) -> Union[tuple, list, dict, None]:
         self.query()
         return self._result
 
-    def one(self) -> Union[list, dict]:
+    def one(self) -> Union[tuple, list, dict, None]:
         self.query(self._sql, self._params, self._FETCH_ONE)
         return self._result
 
@@ -158,10 +159,14 @@ class QueryBuilder:
         self.query(self._sql, self._params, self._NO_FETCH)
         return self._cur.lastrowid
 
-    def column(self, column=0):
+    def column(self, column: int = 0) -> Union[tuple, list, dict, None]:
         self.query('', (), self._FETCH_COLUMN, column)
         return self._result
 
+    def pluck(self, key: int = 0, column: int = 1) -> Union[tuple, list, dict, None]:
+        self.query()
+        return [(x[key], x[column]) for x in self._result]
+
     def count(self, table: Union[str, dict], field: str = ''):
         if table == '' or table == {}:
             self.set_error(f"Empty table in {inspect.stack()[0][3]} method")
@@ -198,26 +203,19 @@ class QueryBuilder:
             for item in items:
                 if isinstance(items, list):
                     if isinstance(item, str):
-                        new_item = item.replace('.', '`.`')
-                        sql.append(f"`{new_item}`")
+                        sql.append(f"{item}")
                     elif isinstance(item, dict):
-                        first_item = list(item.values())[0].replace('.', '`.`')
+                        first_item = list(item.values())[0]
                         alias = list(item.keys())[0]
-                        if first_item.find('(') > -1 or first_item.find(')') > -1:
-                            sql.append(f"{first_item}" if isinstance(alias, int) else f"{first_item} AS `{alias}`")
-                        else:
-                            sql.append(f"`{first_item}`" if isinstance(alias, int) else f"`{first_item}` AS `{alias}`")
+                        sql.append(f"{first_item}" if isinstance(alias, int) else f"{first_item} AS {alias}")
                 elif isinstance(items, dict):
-                    new_item = items[item].replace('.', '`.`')
-                    if new_item.find('(') > -1 or new_item.find(')') > -1:
-                        sql.append(f"{new_item}" if isinstance(item, int) else f"{new_item} AS `{item}`")
-                    else:
-                        sql.append(f"`{new_item}`" if isinstance(item, int) else f"`{new_item}` AS `{item}`")
+                    new_item = items[item]
+                    sql.append(f"{new_item}" if isinstance(item, int) else f"{new_item} AS {item}")
         else:
             self.set_error(f"Incorrect type of items in {inspect.stack()[0][3]} method")
             return ''
 
-        return ', '.join(sql) if not as_list else sql
+        return self._prepare_fieldlist(sql) if not as_list else sql
 
     def _prepare_conditions(self, where: Union[str, list]) -> dict:
         result = {'sql': '', 'values': []}
@@ -231,18 +229,31 @@ class QueryBuilder:
         elif isinstance(where, list):
             for cond in where:
                 if isinstance(cond, list):
-                    if len(cond) == 3:
-                        field = cond[0].replace('.', '`.`')
+                    if len(cond) == 2:
+                        field = self._prepare_field(cond[0])
+                        value = cond[1]
+                        if isinstance(value, list) or isinstance(value, tuple):
+                            operator = 'IN'
+                            values = ("?," * len(value)).rstrip(',')
+                            sql += f"({field} {operator} ({values}))"
+                            for item in value:
+                                result['values'].append(item)
+                        else:
+                            operator = '='
+                            sql += f"({field} {operator} ?)"
+                            result['values'].append(value)
+                    elif len(cond) == 3:
+                        field = self._prepare_field(cond[0])
                         operator = cond[1].upper()
                         value = cond[2]
                         if operator in self._OPERATORS:
                             if operator == 'IN' and (isinstance(value, list) or isinstance(value, tuple)):
                                 values = ("?," * len(value)).rstrip(',')
-                                sql += f"(`{field}` {operator} ({values}))"
+                                sql += f"({field} {operator} ({values}))"
                                 for item in value:
                                     result['values'].append(item)
                             else:
-                                sql += f"({field} {operator} ?)" if field.find('(') > -1 or field.find(')') > -1 else f"(`{field}` {operator} ?)"
+                                sql += f"({field} {operator} ?)"
                                 result['values'].append(value)
                 elif isinstance(cond, str):
                     upper = cond.upper()
@@ -263,18 +274,14 @@ class QueryBuilder:
 
         self.reset()
 
-        if isinstance(fields, dict) or isinstance(fields, list):
+        if isinstance(fields, dict) or isinstance(fields, list) or isinstance(fields, str):
             self._sql = f"SELECT {self._prepare_aliases(fields)}"
-        elif isinstance(fields, str):
-            self._sql = f"SELECT {fields}"
         else:
             self.set_error(f"Incorrect type of fields in {inspect.stack()[0][3]} method. Fields must be String, List or Dictionary")
             return self
 
-        if isinstance(table, dict):
+        if isinstance(table, dict) or isinstance(table, str):
             self._sql += f" FROM {self._prepare_aliases(table)}"
-        elif isinstance(table, str):
-            self._sql += f" FROM `{table}`"
         else:
             self.set_error(f"Incorrect type of table in {inspect.stack()[0][3]} method. Table must be String or Dictionary")
             return self
@@ -336,27 +343,76 @@ class QueryBuilder:
         self._sql += f" OFFSET {offset}"
         return self
 
-    def order_by(self, field: str = '', sort: str = 'ASC'):
-        if field == '' or sort == '':
-            self.set_error(f"Empty field or sort in {inspect.stack()[0][3]} method")
-            return self
+    def _prepare_sorting(self, field: str = '', sort: str = '') -> tuple:
+        if field.find(' ') > -1:
+            splitted = field.split(' ')
+            field = splitted[0]
+            sort = splitted[1]
 
-        sort = sort.upper()
-        field = field.replace('.', '`.`')
+        field = self._prepare_field(field)
 
-        if sort in self._SORT_TYPES:
-            self._sql += f" ORDER BY `{field}` {sort}"
-        else:
-            self._sql += f" ORDER BY `{field}`"
-        return self
+        sort = 'ASC' if sort == '' else sort.upper()
 
-    def group_by(self, field: str = ''):
+        return field, sort
+
+    def _prepare_field(self, field: str = '') -> str:
         if field == '':
+            self.set_error(f"Empty field in {inspect.stack()[0][3]} method")
+            return ''
+
+        if field.find('(') > -1 or field.find(')') > -1 or field.find('*') > -1:
+            if field.find(' AS ') > -1:
+                field = field.replace(' AS ', ' AS `')
+                return f"{field}`"
+            else:
+                return f"{field}"
+        else:
+            field = field.replace('.', '`.`')
+            field = field.replace(' AS ', '` AS `')
+            return f"`{field}`"
+
+    def _prepare_fieldlist(self, fields: Union[str, tuple, list] = ()) -> str:
+        result = ''
+        if fields == '' or fields == () or fields == []:
+            self.set_error(f"Empty fields in {inspect.stack()[0][3]} method")
+            return result
+
+        if isinstance(fields, str):
+            result = self._prepare_field(fields)
+        elif isinstance(fields, tuple) or isinstance(fields, list):
+            fields = [self._prepare_field(field) for field in fields]
+            result = ', '.join(fields)
+
+        return result
+
+    def order_by(self, field: Union[str, tuple, list] = (), sort: str = ''):
+        if field == '' or field == () or field == []:
             self.set_error(f"Empty field in {inspect.stack()[0][3]} method")
             return self
 
-        field = field.replace('.', '`.`')
-        self._sql += f" GROUP BY `{field}`"
+        if isinstance(field, str):
+            field, sort = self._prepare_sorting(field, sort)
+
+            if sort in self._SORT_TYPES:
+                self._sql += f" ORDER BY {field} {sort}"
+            else:
+                self._sql += f" ORDER BY {field}"
+        elif isinstance(field, tuple) or isinstance(field, list):
+            new_list = []
+            for item in field:
+                new_item = self._prepare_sorting(item)
+                new_list.append(f"{new_item[0]} {new_item[1]}")
+            self._sql += ' ORDER BY ' + ', '.join(new_list)
+
+        return self
+
+    def group_by(self, field: Union[str, tuple, list] = ()):
+        if field == '' or field == () or field == []:
+            self.set_error(f"Empty field in {inspect.stack()[0][3]} method")
+            return self
+
+        self._sql += f" GROUP BY {self._prepare_fieldlist(field)}"
+
         return self
 
     def delete(self, table: Union[str, dict]):
@@ -364,10 +420,8 @@ class QueryBuilder:
             self.set_error(f"Empty table in {inspect.stack()[0][3]} method")
             return self
 
-        if isinstance(table, dict):
-            table = f"`{self._prepare_aliases(table)}`"
-        elif isinstance(table, str):
-            table = f"`{table}`"
+        if isinstance(table, dict) or isinstance(table, str):
+            table = self._prepare_aliases(table)
         else:
             self.set_error(f"Incorrect type of table in {inspect.stack()[0][3]} method. Table must be String or Dictionary")
             return self
@@ -382,10 +436,8 @@ class QueryBuilder:
             self.set_error(f"Empty table or fields in {inspect.stack()[0][3]} method")
             return self
 
-        if isinstance(table, dict):
-            table = f"`{self._prepare_aliases(table)}`"
-        elif isinstance(table, str):
-            table = f"`{table}`"
+        if isinstance(table, dict) or isinstance(table, str):
+            table = self._prepare_aliases(table)
         else:
             self.set_error(f"Incorrect type of table in {inspect.stack()[0][3]} method. Table must be String or Dictionary")
             return self
@@ -394,14 +446,14 @@ class QueryBuilder:
 
         if isinstance(fields, dict):
             values = ("?," * len(fields)).rstrip(',')
-            self._sql = f"INSERT INTO {table} (`" + '`, `'.join(list(fields.keys())) + f"`) VALUES ({values})"
+            self._sql = f"INSERT INTO {table} (" + self._prepare_fieldlist(list(fields.keys())) + f") VALUES ({values})"
             self._params = tuple(fields.values())
         elif isinstance(fields, list):
             names = fields.pop(0)
             value = ("?," * len(names)).rstrip(',')
             v = f"({value}),"
             values = (v * len(fields)).rstrip(',')
-            self._sql = f"INSERT INTO {table} (`" + '`, `'.join(names) + f"`) VALUES {values}"
+            self._sql = f"INSERT INTO {table} (" + self._prepare_fieldlist(names) + f") VALUES {values}"
             params = []
             for item in fields:
                 if isinstance(item, list):
@@ -419,10 +471,8 @@ class QueryBuilder:
             self.set_error(f"Empty table or fields in {inspect.stack()[0][3]} method")
             return self
 
-        if isinstance(table, dict):
-            table = f"`{self._prepare_aliases(table)}`"
-        elif isinstance(table, str):
-            table = f"`{table}`"
+        if isinstance(table, dict) or isinstance(table, str):
+            table = self._prepare_aliases(table)
         else:
             self.set_error(f"Incorrect type of table in {inspect.stack()[0][3]} method. Table must be String or Dictionary")
             return self
@@ -430,7 +480,7 @@ class QueryBuilder:
         if isinstance(fields, list) or isinstance(fields, dict):
             sets = ''
             for item in fields:
-                sets += f" `{item.replace('.', '`.`')}` = ?,"
+                sets += f" {self._prepare_field(item)} = ?,"
             sets = sets.rstrip(',')
         else:
             self.set_error(f"Incorrect type of fields in {inspect.stack()[0][3]} method. Fields must be String, List or Dictionary")
@@ -453,18 +503,16 @@ class QueryBuilder:
             self.set_error(f"Empty table in {inspect.stack()[0][3]} method")
             return self
 
-        if isinstance(table, dict):
+        if isinstance(table, dict) or isinstance(table, str):
             self._sql += f" {join_type} JOIN {self._prepare_aliases(table)}"
-        elif isinstance(table, str):
-            self._sql += f" {join_type} JOIN `{table}`"
         else:
             self.set_error(f"Incorrect type of table in {inspect.stack()[0][3]} method. Table must be String or Dictionary")
             return self
 
         if on:
             if isinstance(on, tuple) or isinstance(on, list):
-                field1 = f"`{on[0].replace('.', '`.`')}`"
-                field2 = f"`{on[1].replace('.', '`.`')}`"
+                field1 = self._prepare_field(on[0])
+                field2 = self._prepare_field(on[1])
                 self._sql += f" ON {field1} = {field2}"
             elif isinstance(on, str):
                 self._sql += f" ON {on}"
